@@ -470,4 +470,13 @@ mod tests {
         ).unwrap();
         insta::assert_snapshot!(filename.cache_key(), @"1.2.3.4.5.6.7.8.9.0.1.2.3.4.5.6.7.8.9.0.1.2.1.2-80bf8598e9647cf7");
     }
+
+    /// Don't drop the freethreading tag when there is a debug tag.
+    #[test]
+    fn freethreading_debug() {
+        let filename = "correctionlib-2.8.0-cp314-cp314td-macosx_26_0_arm64.whl";
+        let parsed = WheelFilename::from_str(filename).unwrap();
+        // TODO(konsti): We should preserve the debug tag too, but that requires cache changes.
+        insta::assert_snapshot!(parsed.to_string(), @"correctionlib-2.8.0-cp314-cp314t-macosx_26_0_arm64.whl");
+    }
 }
